@@ -16,7 +16,7 @@ import pandas as pd
 
 def _call_duplication(r):
     """
-    Call whole gene duplication.
+    Call whole gene duplication (3 gene copies total).
     """
     a1, a2 = r.Haplotype1[0], r.Haplotype2[0]
 
@@ -50,12 +50,33 @@ def _call_duplication(r):
 
 def _call_multiplication(r):
     """
-    Call whole gene multiplication.
+    Call whole gene multiplication (4 gene copies total).
     """
     a1, a2 = r.Haplotype1[0], r.Haplotype2[0]
 
-    if a1 == a2:
+    if r.VariantData[a1]:
+        h1 = all([x > 0.6 for x in r.VariantData[a1][1]])
+    else:
+        h1 = True
+
+    if r.VariantData[a2]:
+        h2 = all([x > 0.6 for x in r.VariantData[a2][1]])
+    else:
+        h2 = True
+
+    if h1 and h2:
+        if a1 == a2:
+            result = [a2, a1+'x3']
+        elif r.VariantData[a1] and not r.VariantData[a2]:
+            result = [a2, a1+'x3']
+        elif not r.VariantData[a1] and r.VariantData[a2]:
+            result = [a1, a2+'x3']
+        else:
+            result = ['Indeterminate']
+    elif h1 and not h2:
         result = [a2, a1+'x3']
+    elif not h1 and h2:
+        result = [a1, a2+'x3']
     else:
         result = ['Indeterminate']
 
@@ -193,6 +214,17 @@ class CYP2D6Genotyper:
                 result = [a1, '*36x3+*10']
             else:
                 result = ['Indeterminate']
+        elif r.CNV == 'Tandem3':
+            h1 = '*1' in r.Haplotype1
+            h2 = '*1' in r.Haplotype2
+            if h1 and h2:
+                result = ['*1', '*13+*1']
+            elif h1 and not h2:
+                result = [a2, '*13+*1']
+            elif not h1 and h2:
+                result = [a1, '*13+*1']
+            else:
+                result = ['Indeterminate']
         elif 'DeletionHet' in r.CNV and 'Tandem1' in r.CNV:
             if '*4' in a1 or '*4' in a2:
                 result = ['*5', '*68+*4']
@@ -252,6 +284,27 @@ class CYP2E1Genotyper:
         self.assembly = assembly
         self.results = df.apply(self.one_row, axis=1)
 
+class CYP4F2Genotyper:
+    """
+    Genotyper for CYP4F2.
+    """
+
+    def one_row(self, r):
+        a1, a2 = r.Haplotype1[0], r.Haplotype2[0]
+        s1, s2 = core.sort_alleles([a1, a2], by='priority', gene=self.gene, assembly=self.assembly)
+        if r.CNV in ['Normal', 'AssumeNormal']:
+            result = [a1, a2]
+        elif r.CNV == 'DeletionHet':
+            result = [s1, '*DEL']
+        else:
+            result = ['Indeterminate']
+        return '/'.join(core.sort_alleles(result, by='name'))
+
+    def __init__(self, df, assembly):
+        self.gene = 'CYP4F2'
+        self.assembly = assembly
+        self.results = df.apply(self.one_row, axis=1)
+
 class GSTM1Genotyper:
     """
     Genotyper for GSTM1.
@@ -340,6 +393,33 @@ class SLC22A2Genotyper:
         self.assembly = assembly
         self.results = df.apply(self.one_row, axis=1)
 
+class SULT1A1Genotyper:
+    """
+    Genotyper for SULT1A1.
+    """
+
+    def one_row(self, r):
+        a1, a2 = r.Haplotype1[0], r.Haplotype2[0]
+        s1, s2 = core.sort_alleles([a1, a2], by='priority', gene=self.gene, assembly=self.assembly)
+        if r.CNV in ['Normal', 'AssumeNormal']:
+            result = [a1, a2]
+        elif r.CNV == 'DeletionHet':
+            result = [s1, '*DEL']
+        elif r.CNV == 'Duplication':
+            result = _call_duplication(r)
+        elif r.CNV == 'Multiplication1':
+            result = _call_multiplication(r)
+        elif r.CNV == 'Multiplication2':
+            result = ['Indeterminate']
+        else:
+            result = ['Indeterminate']
+        return '/'.join(core.sort_alleles(result, by='name'))
+
+    def __init__(self, df, assembly):
+        self.gene = 'SULT1A1'
+        self.assembly = assembly
+        self.results = df.apply(self.one_row, axis=1)
+
 class UGT1A4Genotyper:
     """
     Genotyper for UGT1A4.
@@ -439,9 +519,11 @@ def call_genotypes(alleles=None, cnv_calls=None):
         'CYP2B6': CYP2B6Genotyper,
         'CYP2D6': CYP2D6Genotyper,
         'CYP2E1': CYP2E1Genotyper,
+        'CYP4F2': CYP4F2Genotyper,
         'GSTM1': GSTM1Genotyper,
         'GSTT1': GSTT1Genotyper,
         'SLC22A2': SLC22A2Genotyper,
+        'SULT1A1': SULT1A1Genotyper,
         'UGT1A4': UGT1A4Genotyper,
         'UGT2B15': UGT2B15Genotyper,
         'UGT2B17': UGT2B17Genotyper,
