@@ -6,32 +6,30 @@ import fuc
 import pysam
 
 description = f"""
-###########################################
-# Train a CNV caller for the target gene. #
-###########################################
+Train a CNV caller for the target gene.
 
-This command will return a SVM-based multiclass classifier that makes CNV calls using the one-vs-rest stategy.
-
-Usage examples:
-  $ pypgx {fuc.api.common._script_name()} CYP2D6-copy-number.zip CYP2D6-cnv-calls.zip CYP2D6-cnv-caller.zip
+This command will return a SVM-based multiclass classifier that makes CNV
+calls using the one-vs-rest strategy.
 """
 
 def create_parser(subparsers):
     parser = fuc.api.common._add_parser(
         subparsers,
         fuc.api.common._script_name(),
-        help='Train a CNV caller for the target gene.',
         description=description,
+        help='Train a CNV caller for the target gene.',
     )
     parser.add_argument(
         'copy_number',
         metavar='copy-number',
-        help='Archive file with the semantic type CovFrame[CopyNumber]'
+        help='Archive file with the semantic type \n'
+             'CovFrame[CopyNumber].'
     )
     parser.add_argument(
         'cnv_calls',
         metavar='cnv-calls',
-        help='Archive file with the semantic type SampleTable[CNVCalls].'
+        help='Archive file with the semantic type \n'
+             'SampleTable[CNVCalls].'
     )
     parser.add_argument(
         'cnv_caller',
